==> webkit2gtk_2.50.4.orig.tar.xz: webkitgtk-2.50.4/Source/JavaScriptCore/runtime/NativeCallee.cpp <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "NativeCallee.h"

#include "LLIntExceptions.h"
#include "NativeCalleeRegistry.h"
#include "WasmCallee.h"

namespace JSC {

NativeCallee::NativeCallee(Category category, ImplementationVisibility implementationVisibility)
    : m_category(category)
    , m_implementationVisibility(implementationVisibility)
{
}

void NativeCallee::dump(PrintStream& out) const
{
    switch (category()) {
    case Category::Wasm: {
#if ENABLE(WEBASSEMBLY)
        static_cast<const Wasm::Callee*>(this)->dump(out);
#endif
        break;
    }
    case Category::InlineCache: {
        out.print(RawPointer(this));
        break;
    }
    }
}

void NativeCallee::operator delete(NativeCallee* callee, std::destroying_delete_t)
{
    NativeCalleeRegistry::singleton().unregisterCallee(callee);
    switch (callee->category()) {
    case Category::Wasm: {
#if ENABLE(WEBASSEMBLY)
        Wasm::Callee::destroy(static_cast<Wasm::Callee*>(callee));
#endif
        break;
    }
    case Category::InlineCache: {
        break;
    }
    }
}

} // namespace JSC

==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Source/JavaScriptCore/runtime/NativeCallee.cpp <==
/*
 * Copyright (C) 2023 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "NativeCallee.h"

#include "LLIntExceptions.h"
#include "NativeCalleeRegistry.h"
#include "WasmCallee.h"

namespace JSC {

NativeCallee::NativeCallee(Category category, ImplementationVisibility implementationVisibility)
    : m_category(category)
    , m_implementationVisibility(implementationVisibility)
{
}

void NativeCallee::dump(PrintStream& out) const
{
    switch (category()) {
    case Category::Wasm: {
#if ENABLE(WEBASSEMBLY)
        uncheckedDowncast<const Wasm::Callee>(this)->dump(out);
#endif
        break;
    }
    case Category::InlineCache: {
        out.print(RawPointer(this));
        break;
    }
    }
}

void NativeCallee::operator delete(NativeCallee* callee, std::destroying_delete_t)
{
    NativeCalleeRegistry::singleton().unregisterCallee(callee);
    switch (callee->category()) {
    case Category::Wasm: {
#if ENABLE(WEBASSEMBLY)
        Wasm::Callee::destroy(uncheckedDowncast<Wasm::Callee>(callee));
#endif
        break;
    }
    case Category::InlineCache: {
        break;
    }
    }
}

} // namespace JSC
